@@ -12,6 +12,7 @@ from nltk.stem import PorterStemmer
 from nltk.stem.isri import ISRIStemmer
 from tqdm import tqdm
 from collections import Counter
+from huggingface_hub.utils._errors import HTTPError
 download('stopwords')
 
 
@@ -94,7 +95,7 @@ class sentence_tranformer_checker():
         target_group: Optional[Union[List[str], pd.DataFrame]]=None,
         target_col: Optional[str]=None, 
         device: Optional[str] = None,
-        model: Optional[SentenceTransformer]=None, 
+        model: Optional[str]=None, 
         lang: Optional[str]='en', 
         only_include: Optional[List[str]]=None,
         encode_batch: Optional[int] = 32,
@@ -125,7 +126,7 @@ class sentence_tranformer_checker():
         self.remove_stop_words = remove_stop_words
         self.stemm = stemm
         self.lang = lang 
-        
+
         if device is None:
             self.device = None
         else:
@@ -175,10 +176,13 @@ class sentence_tranformer_checker():
         if pd.isnull(self.target_names).any():
             raise ValueError('Targets contain null values')
 
-        self.model = model
-        self.model.device = device
+        if model is not None:
+            try:
+                self.model = SentenceTransformer(model, device=device)
+            except HTTPError:
+                raise HTTPError('entered model name is not defined')
         # if no model is provided use the default model
-        if model is None:
+        else:
             print('initializing the model...')
             if lang.lower() == 'en':
                 self.model = SentenceTransformer('all-MiniLM-L6-v2', device=device)
